<?php
$this->js_css->parse_js('ciext_help/js/main.js');
$this->js_css->parse_js('ciext_help/js/cookie.js');
?>
<div class="container container-helper">
    <div class="span8 user_guide_content">
        <!--content-->
        <?= !empty($file) ? $file : ''; ?>
        <!--error-->
        <?php if (!empty($error)): ?>
            <span class="error"><?= $error ?></span>
        <?php endif; ?>
    </div>
    <!--list-->
    <div class="span4 user_guide_tree">
        <?= get_help_list($files, '', $current); ?>
        <?php if ($this->rt_user->isAllowed('ciext_help', 'view_ciext_help')) : ?>
            <ul>
                <li><a href="/<?= $this->config->item('admin_page') ?>/mconfig/index/ciext_help/documentation">&nbsp;&nbsp;&nbsp;<?= $this->lang->line('Modules documentation') ?></a>
                </li>
            </ul>
        <?php endif; ?>
    </div>
</div>
