<div class="container container-helper">
    <h2><?= $this->lang->line('Ciext help') ?></h2>
    <p><?= $this->lang->line('Select the desired module and check the left developer documentation') ?></p>
    <div class="modules-list">
        <?php if (!empty($modules)): ?>
            <div class="tabbable tabs-left">
                <ul class="nav nav-tabs">
                    <?php foreach ($modules as $key => $module): ?>
                        <li class="<?= ($key == 0) ? 'active' : '' ?>">
                            <a href="#module<?= $key ?>" data-toggle="tab"><?= $module['name'] ?></a>
                        </li>
                    <?php endforeach; ?>
                </ul>
                <div class="tab-content">
                    <?php foreach ($modules as $key => $module): ?>
                        <div class="tab-pane <?= ($key == 0) ? 'active' : '' ?>" id="module<?= $key ?>">
                            <?= $module['content'] ?>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
    </div>
</div>