<?php
if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

require_once dirname(dirname(dirname(dirname(BASEPATH)))).'/vendor/erusev/parsedown/Parsedown.php';

/**
 * Readme file parser
 *
 * @author Roman Ratsun
 */
class readme_parser extends Parsedown
{

}
